@@ -34,10 +34,8 @@ from typing import (
 )
 
 from robotcode.core.lsp.types import Position, Range
-from robotcode.language_server.robotframework.utils.markdownformatter import (
-    MarkDownFormatter,
-)
 from robotcode.robot.utils import get_robot_version
+from robotcode.robot.utils.markdownformatter import MarkDownFormatter
 
 from ..utils.ast_utils import (
     HasError,
@@ -263,7 +261,6 @@ class TypeDoc:
     usages: List[str] = field(default_factory=list)
     members: Optional[List[EnumMember]] = None
     items: Optional[List[TypedDictItem]] = None
-
     libname: Optional[str] = None
     libtype: Optional[str] = None
 
@@ -390,7 +387,7 @@ class ArgumentInfo:
             str_repr=str(arg),
             types=robot_arg.types_reprs
             if get_robot_version() < (7, 0)
-            else [str(robot_arg.type)]
+            else ([str(robot_arg.type)] if not robot_arg.type.is_union else [str(t) for t in robot_arg.type.nested])
             if robot_arg.type
             else None,
             kind=KeywordArgumentKind[robot_arg.kind],
@@ -443,7 +440,8 @@ class ArgumentSpec:
     var_named: Any
     embedded: Any
     defaults: Any
-    types: Any
+    types: Optional[Dict[str, str]] = None
+    return_type: Optional[str] = None
 
     @staticmethod
     def from_robot_argument_spec(spec: Any) -> ArgumentSpec:
@@ -457,7 +455,8 @@ class ArgumentSpec:
             var_named=spec.var_named,
             embedded=spec.embedded if get_robot_version() >= (7, 0) else None,
             defaults={k: str(v) for k, v in spec.defaults.items()} if spec.defaults else {},
-            types=None,
+            types={k: str(v) for k, v in spec.types.items()} if get_robot_version() > (7, 0) and spec.types else None,
+            return_type=str(spec.return_type) if get_robot_version() > (7, 0) and spec.return_type else None,
         )
 
     def resolve(
@@ -490,7 +489,7 @@ class ArgumentSpec:
                     self.named_only,
                     self.var_named,
                     self.defaults,
-                    self.types,
+                    None,
                 )
             else:
                 self.__robot_arguments = RobotArgumentSpec(
@@ -503,7 +502,7 @@ class ArgumentSpec:
                     self.var_named,
                     self.embedded,
                     self.defaults,
-                    self.types,
+                    None,
                 )
         self.__robot_arguments.name = self.name
         if validate:
@@ -554,6 +553,7 @@ class KeywordDoc(SourceEntity):
     is_registered_run_keyword: bool = field(default=False, compare=False)
     args_to_process: Optional[int] = field(default=None, compare=False)
     deprecated: bool = field(default=False, compare=False)
+    return_type: Optional[str] = field(default=None, compare=False)
 
     parent_digest: Optional[str] = field(default=None, init=False, metadata={"nosave": True})
     parent: Optional[LibraryDoc] = field(default=None, init=False, metadata={"nosave": True})
@@ -720,6 +720,11 @@ class KeywordDoc(SourceEntity):
                     f"| {'=' if a.default_value is not None else ''} "
                     f"| {f'`{a.default_value!s}`' if a.default_value else ''} |"
                 )
+        if self.return_type:
+            if result:
+                result += "\n\n"
+
+            result += f"**Return Type**: `{self.return_type}`\n"
 
         if self.tags:
             if result:
@@ -1802,6 +1807,7 @@ def get_library_doc(
                             arguments_spec=ArgumentSpec.from_robot_argument_spec(kw[1].arguments)
                             if not kw[1].is_error_handler
                             else None,
+                            return_type=str(kw[1].arguments.return_type) if get_robot_version() >= (7, 0) else None,
                         )
                         for kw in keyword_docs
                     ],
@@ -1824,7 +1830,10 @@ def get_library_doc(
                                 kw.type_docs[arg.name] = {}
                                 for type_info in _yield_type_info(arg.type):
                                     if type_info.type is not None:
-                                        type_doc = RobotTypeDoc.for_type(type_info.type, custom_converters)
+                                        if get_robot_version() < (7, 0):
+                                            type_doc = RobotTypeDoc.for_type(type_info.type, custom_converters)
+                                        else:
+                                            type_doc = RobotTypeDoc.for_type(type_info, custom_converters)
                                         if type_doc:
                                             kw.type_docs[arg.name][type_info.name] = type_doc.name
                                             type_docs.setdefault(type_doc, set()).add(kw.name)
