@@ -11,11 +11,13 @@ from robotcode.jsonrpc2.protocol import JsonRPCErrorException, JsonRPCErrors, Pr
 from robotcode.language_server.common.parts.document_symbols import symbol_information_label
 from robotcode.language_server.common.protocol import LanguageDefinition, LanguageServerProtocol
 from robotcode.robot.config.model import RobotBaseProfile
+from robotcode.robot.utils import get_robot_version
 
 from ..__version__ import __version__
 from .configuration import RobotConfig
 from .parts.code_action_documentation import RobotCodeActionDocumentationProtocolPart
-from .parts.code_action_fixes import RobotCodeActionFixesProtocolPart
+from .parts.code_action_quick_fixes import RobotCodeActionQuickFixesProtocolPart
+from .parts.code_action_refactor import RobotCodeActionRefactorProtocolPart
 from .parts.codelens import RobotCodeLensProtocolPart
 from .parts.completion import RobotCompletionProtocolPart
 from .parts.debugging_utils import RobotDebuggingUtilsProtocolPart
@@ -36,7 +38,6 @@ from .parts.robot_workspace import RobotWorkspaceProtocolPart
 from .parts.selection_range import RobotSelectionRangeProtocolPart
 from .parts.semantic_tokens import RobotSemanticTokenProtocolPart
 from .parts.signature_help import RobotSignatureHelpProtocolPart
-from .utils.version import get_robot_version
 
 if TYPE_CHECKING:
     from .server import RobotLanguageServer
@@ -79,6 +80,7 @@ class RobotLanguageServerProtocol(LanguageServerProtocol):
     _logger: Final = LoggingDescriptor()
 
     documents_cache = ProtocolPartDescriptor(DocumentsCache)
+    robot_workspace = ProtocolPartDescriptor(RobotWorkspaceProtocolPart)
     robot_diagnostics = ProtocolPartDescriptor(RobotDiagnosticsProtocolPart)
     robot_folding_ranges = ProtocolPartDescriptor(RobotFoldingRangeProtocolPart)
     robot_goto = ProtocolPartDescriptor(RobotGotoProtocolPart)
@@ -97,8 +99,8 @@ class RobotLanguageServerProtocol(LanguageServerProtocol):
     robot_inline_value = ProtocolPartDescriptor(RobotInlineValueProtocolPart)
     robot_inlay_hint = ProtocolPartDescriptor(RobotInlayHintProtocolPart)
     robot_code_action_documentation = ProtocolPartDescriptor(RobotCodeActionDocumentationProtocolPart)
-    robot_code_action_fixes = ProtocolPartDescriptor(RobotCodeActionFixesProtocolPart)
-    robot_workspace = ProtocolPartDescriptor(RobotWorkspaceProtocolPart)
+    robot_code_action_quick_fixes = ProtocolPartDescriptor(RobotCodeActionQuickFixesProtocolPart)
+    robot_code_action_refactor = ProtocolPartDescriptor(RobotCodeActionRefactorProtocolPart)
 
     robot_debugging_utils = ProtocolPartDescriptor(RobotDebuggingUtilsProtocolPart)
 
